;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "keymap-utils" "20251011.1822"
  "Keymap utilities."
  '((emacs  "28.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/keymap-utils"
  :commit "d0e5672aba7f3482414c1a87003de3d87b2cab5c"
  :revdesc "d0e5672aba7f"
  :keywords '("convenience" "extensions")
  :authors '(("Jonas Bernoulli" . "emacs.keymap-utils@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.keymap-utils@jonas.bernoulli.dev")))
